*****************************
The sherpa.astro.utils module
*****************************

.. currentmodule:: sherpa.astro.utils

.. automodule:: sherpa.astro.utils

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      apply_pileup
      arf_fold
      calc_data_sum
      calc_data_sum2d
      calc_energy_flux
      calc_kcorr
      calc_model_sum
      calc_model_sum2d
      calc_photon_flux
      calc_source_sum
      compile_energy_grid
      do_group
      eqwidth
      expand_grouped_mask
      filter_resp
      get_xspec_norm
      get_xspec_position
      is_in
      rmf_fold
      shrink_effarea
